@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package Dancer2::Plugin::JWT;
 # ABSTRACT: JSON Web Token made simple for Dancer2
-$Dancer2::Plugin::JWT::VERSION = '0.003';
+$Dancer2::Plugin::JWT::VERSION = '0.004';
 use Dancer2::Plugin;
 use JSON::WebToken;
 use URI;
@@ -34,12 +34,19 @@ register jwt => sub {
 on_plugin_import {
 	my $dsl = shift;
 
+	$dsl->hook(
+		before_template => sub {
+		   my $tokens = shift;
+		   $tokens->{jwt} = request->var('jwt');
+		}
+	);
+
 	$dsl->hook(
 		before => sub {
 				my $app = shift;
 				my $encoded = $app->request->headers->authorization;
 
-				if (!$encoded && $app->request->param('_jwt')) {
+				if ($app->request->param('_jwt')) {
 					$encoded = $app->request->param('_jwt');
 				}
 
@@ -50,7 +57,7 @@ on_plugin_import {
 						$decoded = decode_jwt($encoded, $secret);
 					};
 					if ($@) {
-						$dsl->execute_hook('jwt_exception' => $@);
+						$dsl->execute_hook('jwt_exception' => ($a = $@));
 					};
 					$app->request->var('jwt', $decoded);
 				}
